@@ -21,7 +21,7 @@
  */
 
 /**
- * search class
+ * @class Services_Hatena_search
  *
  * This is search class.
  *
@@ -36,12 +36,24 @@ class Services_Hatena_search extends Services_Hatena_base {
     protected $osxml_url = "http://search.hatena.ne.jp/osxml";
     protected $os     = null;
 
-    public function Services_Hatena_search()
-    {
+    /**
+     * @fn Services_Hatena_search
+     * @brief constructer for Services_Hatena_search class
+     *
+     * @access  public
+     */
+    public function Services_Hatena_search() {
         require_once 'Services/OpenSearch.php';
         $this->os = new Services_OpenSearch($this->osxml_url);
     }
 
+    /**
+     * @fn execute
+     * @brief search with OpernSearch
+     *
+     * @access  public
+     * @return  array search result
+     */
     public function execute($keyword) {
         $this->result = $this->os->search($keyword);
         return $this->getResult();
